@@ -1,5 +1,5 @@
 # Copyright (C) 2007 Jan-Klaas Kollhof
-# Copyright (C) 2011-2015 The python-bitcoinlib developers
+# Copyright (C) 2011-2018 The python-bitcoinlib developers
 #
 # This file is part of python-bitcoinlib.
 #
@@ -142,39 +142,49 @@ class BaseProxy(object):
                     btc_conf_file = os.path.expanduser('~/.bitcoin')
                 btc_conf_file = os.path.join(btc_conf_file, 'bitcoin.conf')
 
+            # Bitcoin Core accepts empty rpcuser, not specified in btc_conf_file
+            conf = {'rpcuser': ""}
+
             # Extract contents of bitcoin.conf to build service_url
-            with open(btc_conf_file, 'r') as fd:
-                # Bitcoin Core accepts empty rpcuser, not specified in btc_conf_file
-                conf = {'rpcuser': ""}
-                for line in fd.readlines():
-                    if '#' in line:
-                        line = line[:line.index('#')]
-                    if '=' not in line:
-                        continue
-                    k, v = line.split('=', 1)
-                    conf[k.strip()] = v.strip()
+            try:
+                with open(btc_conf_file, 'r') as fd:
+                    for line in fd.readlines():
+                        if '#' in line:
+                            line = line[:line.index('#')]
+                        if '=' not in line:
+                            continue
+                        k, v = line.split('=', 1)
+                        conf[k.strip()] = v.strip()
 
-                if service_port is None:
-                    service_port = bitcoin.params.RPC_PORT
-                conf['rpcport'] = int(conf.get('rpcport', service_port))
-                conf['rpchost'] = conf.get('rpcconnect', 'localhost')
+            # Treat a missing bitcoin.conf as though it were empty
+            except FileNotFoundError:
+                pass
 
-                service_url = ('%s://%s:%d' %
-                    ('http', conf['rpchost'], conf['rpcport']))
+            if service_port is None:
+                service_port = bitcoin.params.RPC_PORT
+            conf['rpcport'] = int(conf.get('rpcport', service_port))
+            conf['rpchost'] = conf.get('rpcconnect', 'localhost')
 
-                cookie_dir = os.path.dirname(btc_conf_file)
-                if bitcoin.params.NAME != "mainnet":
-                    cookie_dir = os.path.join(cookie_dir, bitcoin.params.NAME)
-                cookie_file = os.path.join(cookie_dir, ".cookie")
-                try:
-                    with open(cookie_file, 'r') as fd:
-                        authpair = fd.read()
-                except IOError as err:
-                    if 'rpcpassword' in conf:
-                        authpair = "%s:%s" % (conf['rpcuser'], conf['rpcpassword'])
+            service_url = ('%s://%s:%d' %
+                ('http', conf['rpchost'], conf['rpcport']))
 
-                    else:
-                        raise ValueError('Cookie file unusable (%s) and rpcpassword not specified in the configuration file: %r' % (err, btc_conf_file))
+            cookie_dir = conf.get('datadir', os.path.dirname(btc_conf_file))
+            if bitcoin.params.NAME != "mainnet":
+                cookie_dir = os.path.join(cookie_dir, bitcoin.params.NAME)
+            cookie_file = os.path.join(cookie_dir, ".cookie")
+            try:
+                with open(cookie_file, 'r') as fd:
+                    authpair = fd.read()
+            except IOError as err:
+                if 'rpcpassword' in conf:
+                    authpair = "%s:%s" % (conf['rpcuser'], conf['rpcpassword'])
+
+                else:
+                    raise ValueError('Cookie file unusable (%s) and rpcpassword not specified in the configuration file: %r' % (err, btc_conf_file))
+
+        else:
+            url = urlparse.urlparse(service_url)
+            authpair = "%s:%s" % (url.username, url.password)
 
         self.__service_url = service_url
         self.__url = urlparse.urlparse(service_url)
@@ -297,7 +307,7 @@ class Proxy(BaseProxy):
     Unlike ``RawProxy``, data is passed as ``bitcoin.core`` objects or packed
     bytes, rather than JSON or hex strings. Not all methods are implemented
     yet; you can use ``call`` to access missing ones in a forward-compatible
-    way. Assumes Bitcoin Core version >= v0.15.0; older versions mostly work,
+    way. Assumes Bitcoin Core version >= v0.16.0; older versions mostly work,
     but there are a few incompatibilities.
     """
 
